@@ -139,7 +139,7 @@ Another way is to use message passing:
         }
     }
 ```
-For the remainder of the code, check the full example [here](https://github.com/fltk-rs/fltk-rs/blob/master/examples/counter2.rs).
+For the remainder of the code, check the full example [here](https://github.com/fltk-rs/fltk-rs/blob/master/fltk/examples/counter2.rs).
 
 For custom event handling, the handle() method can be used:
 ```rust,ignore
